[med-svn] [r-bioc-biocgenerics] 02/05: Imported Upstream version 0.8.0
Charles Plessy
plessy at alioth.debian.org
Thu Oct 17 06:13:14 UTC 2013
This is an automated email from the git hooks/post-receive script.
plessy pushed a commit to branch master
in repository r-bioc-biocgenerics.
commit cbaf052c08b28c583ef498eef9786d8b068ccb0f
Author: Charles Plessy <plessy at debian.org>
Date: Thu Oct 17 15:03:29 2013 +0900
Imported Upstream version 0.8.0
---
DESCRIPTION | 22 ++++++------
NAMESPACE | 27 +++++++++++++--
R/annotation.R | 7 ++--
R/{tapply.R => append.R} | 8 ++---
R/{tapply.R => as.vector.R} | 8 ++---
R/combine.R | 2 +-
R/dge.R | 18 ++++++++++
R/eval.R | 4 +++
R/is.unsorted.R | 8 +++++
R/normalize.R | 8 +++++
R/normarg-utils.R | 31 +++++++++++++++++
R/plotMA.R | 10 ++++++
R/show-utils.R | 60 ++++++++++++++++++++++++++++++++
R/tapply.R | 4 +--
R/update.R | 41 ++++++++++++++++++++++
TODO | 4 ---
man/BiocGenerics-package.Rd | 20 +++++++----
man/Extremes.Rd | 26 +++++++-------
man/annotation.Rd | 20 ++++++-----
man/append.Rd | 72 ++++++++++++++++++++++++++++++++++++++
man/as.data.frame.Rd | 32 +++++++++--------
man/as.vector.Rd | 73 +++++++++++++++++++++++++++++++++++++++
man/boxplot.Rd | 24 +++++++------
man/cbind.Rd | 32 +++++++++--------
man/clusterApply.Rd | 17 +++++----
man/combine.Rd | 28 ++++++++-------
man/density.Rd | 24 +++++++------
man/dge.Rd | 51 +++++++++++++++++++++++++++
man/duplicated.Rd | 28 ++++++++-------
man/eval.Rd | 25 ++++++++------
man/evalq.Rd | 51 +++++++++++++++++++++++++++
man/funprog.Rd | 34 +++++++++---------
man/get.Rd | 26 +++++++-------
man/image.Rd | 24 +++++++------
man/is.unsorted.Rd | 80 +++++++++++++++++++++++++++++++++++++++++++
man/lapply.Rd | 28 ++++++++-------
man/mapply.Rd | 25 ++++++++------
man/match.Rd | 24 +++++++------
man/normalize.Rd | 61 +++++++++++++++++++++++++++++++++
man/nrow.Rd | 28 ++++++++-------
man/order.Rd | 24 +++++++------
man/paste.Rd | 26 +++++++-------
man/plotMA.Rd | 55 +++++++++++++++++++++++++++++
man/rank.Rd | 25 +++++++-------
man/rep.Rd | 28 ++++++++-------
man/residuals.Rd | 24 +++++++------
man/row_colnames.Rd | 28 ++++++++-------
man/sets.Rd | 28 ++++++++-------
man/sort.Rd | 26 +++++++-------
man/strand.Rd | 20 ++++++-----
man/table.Rd | 24 +++++++------
man/tapply.Rd | 25 ++++++++------
man/unique.Rd | 31 +++++++++--------
man/unlist.Rd | 26 +++++++-------
man/updateObject.Rd | 24 +++++++------
man/weights.Rd | 24 +++++++------
man/xtabs.Rd | 25 ++++++++------
57 files changed, 1152 insertions(+), 426 deletions(-)
diff --git a/DESCRIPTION b/DESCRIPTION
index 8e11449..ec244f1 100644
--- a/DESCRIPTION
+++ b/DESCRIPTION
@@ -1,7 +1,7 @@
Package: BiocGenerics
Title: Generic functions for Bioconductor
Description: S4 generic functions needed by many Bioconductor packages.
-Version: 0.6.0
+Version: 0.8.0
Author: The Bioconductor Dev Team
Maintainer: Bioconductor Package Maintainer
<maintainer at bioconductor.org>
@@ -9,13 +9,15 @@ biocViews: Infrastructure
Depends: methods, graphics, stats, parallel
Imports: methods, graphics, stats, parallel
Suggests: Biobase, IRanges, GenomicRanges, AnnotationDbi, oligoClasses,
- oligo, affyPLM, flowClust, RUnit
+ oligo, affyPLM, flowClust, affy, RUnit, DESeq2
License: Artistic-2.0
-Collate: S3-classes-as-S4-classes.R as.data.frame.R cbind.R
- duplicated.R eval.R Extremes.R funprog.R get.R lapply.R
- mapply.R match.R nrow.R order.R paste.R rank.R rep.R
- row_colnames.R sets.R sort.R table.R tapply.R unique.R unlist.R
- boxplot.R image.R density.R residuals.R weights.R xtabs.R
- clusterApply.R annotation.R combine.R strand.R updateObject.R
- testPackage.R test_BiocGenerics_package.R zzz.R
-Packaged: 2013-04-04 08:27:12 UTC; biocbuild
+Collate: S3-classes-as-S4-classes.R append.R as.data.frame.R
+ as.vector.R cbind.R dge.R plotMA.R duplicated.R eval.R
+ Extremes.R funprog.R get.R is.unsorted.R lapply.R mapply.R
+ match.R nrow.R order.R paste.R rank.R rep.R row_colnames.R
+ sets.R sort.R table.R tapply.R unique.R unlist.R boxplot.R
+ image.R density.R residuals.R weights.R xtabs.R clusterApply.R
+ annotation.R combine.R normalize.R normarg-utils.R show-utils.R
+ strand.R updateObject.R update.R testPackage.R
+ test_BiocGenerics_package.R zzz.R
+Packaged: 2013-10-15 04:35:59 UTC; biocbuild
diff --git a/NAMESPACE b/NAMESPACE
index 4cb486b..a850e37 100644
--- a/NAMESPACE
+++ b/NAMESPACE
@@ -22,9 +22,15 @@ exportClasses(
### Generics for functions defined in package base:
export(
+ ## from R/append.R:
+ append,
+
## from R/as.data.frame.R:
as.data.frame,
+ ## from R/as.vector.R:
+ as.vector,
+
## from R/cbind.R:
cbind, rbind,
@@ -32,7 +38,7 @@ export(
duplicated, anyDuplicated,
## from R/eval.R:
- eval,
+ eval, evalq,
## from R/Extremes.R:
pmax, pmin, pmax.int, pmin.int,
@@ -43,6 +49,9 @@ export(
## from R/get.R:
get, mget,
+ ## from R/is.unsorted.R:
+ is.unsorted,
+
## from R/lapply.R:
lapply, sapply,
@@ -135,6 +144,9 @@ export(
## from R/combine.R:
combine,
+ ## from R/normalize.R:
+ normalize,
+
## from R/strand.R:
strand, "strand<-",
@@ -149,6 +161,17 @@ exportMethods(
combine,
## from R/updateObject.R:
- updateObject
+ updateObject,
+
+ ## from R/dge.R:
+ counts, "counts<-",
+ design, "design<-",
+ dispTable, "dispTable<-",
+ sizeFactors, "sizeFactors<-",
+ conditions, "conditions<-",
+ estimateSizeFactors,
+ estimateDispersions,
+ plotDispEsts,
+ plotMA
)
diff --git a/R/annotation.R b/R/annotation.R
index f8ae829..5a6931d 100644
--- a/R/annotation.R
+++ b/R/annotation.R
@@ -3,7 +3,10 @@
### -------------------------------------------------------------------------
setGeneric("annotation",
- function(object, ...) standardGeneric("annotation"))
+ function(object, ...) standardGeneric("annotation")
+)
setGeneric("annotation<-",
- function(object, ..., value) standardGeneric("annotation<-"))
+ function(object, ..., value) standardGeneric("annotation<-")
+)
+
diff --git a/R/tapply.R b/R/as.vector.R
similarity index 57%
copy from R/tapply.R
copy to R/as.vector.R
index 79d6c9d..cde98a5 100644
--- a/R/tapply.R
+++ b/R/as.vector.R
@@ -1,10 +1,10 @@
### =========================================================================
-### The tapply() generic
+### The as.vector() generic
### -------------------------------------------------------------------------
###
### Need to explicitly define this generic otherwise the implicit generic in
-### package "base" would dispatch on all its arguments. Here we set dispatch
-### on the 1st arg (the 'X' arg) only!
+### package "base" would dispatch on ('x', 'mode'). Here we set dispatch on
+### the 1st arg (the 'x' arg) only!
-setGeneric("tapply", signature="X")
+setGeneric("as.vector", signature="x")
diff --git a/R/combine.R b/R/combine.R
index 99f9e84..676e73e 100644
--- a/R/combine.R
+++ b/R/combine.R
@@ -10,7 +10,7 @@ setGeneric("combine",
function(x, y, ...)
{
if (length(list(...)) > 0L) {
- callGeneric(x, do.call(callGeneric, list(y, ...)))
+ combine(x, do.call(combine, list(y, ...)))
} else {
standardGeneric("combine")
}
diff --git a/R/dge.R b/R/dge.R
new file mode 100644
index 0000000..0c1d372
--- /dev/null
+++ b/R/dge.R
@@ -0,0 +1,18 @@
+# Currently, these are for DESeq and DEXSeq. Could be extended to a more general
+# infrastructure for count datasets.
+setGeneric("counts", function(object, ...) standardGeneric("counts"))
+setGeneric("counts<-", function(object, ..., value) standardGeneric("counts<-"))
+setGeneric("dispTable", function(object, ...) standardGeneric("dispTable"))
+setGeneric("dispTable<-", function(object, ..., value) standardGeneric("dispTable<-"))
+setGeneric("sizeFactors", function(object, ...) standardGeneric("sizeFactors"))
+setGeneric("sizeFactors<-", function(object, ..., value) standardGeneric("sizeFactors<-"))
+
+setGeneric("conditions", function(object, ...) standardGeneric("conditions"))
+setGeneric("conditions<-", function(object, ..., value) standardGeneric("conditions<-"))
+setGeneric("design", function(object, ...) standardGeneric("design"))
+setGeneric("design<-", function(object, ..., value) standardGeneric("design<-"))
+
+setGeneric("estimateSizeFactors", function(object, ...) standardGeneric("estimateSizeFactors"))
+setGeneric("estimateDispersions", function(object, ...) standardGeneric("estimateDispersions"))
+setGeneric("plotDispEsts", function(object, ...) standardGeneric("plotDispEsts"))
+
diff --git a/R/eval.R b/R/eval.R
index 838cec7..cd212b8 100644
--- a/R/eval.R
+++ b/R/eval.R
@@ -17,3 +17,7 @@ setGeneric("eval", signature=c("expr", "envir"),
}
)
+evalq <- function(expr, envir = parent.frame(),
+ enclos = if (is.list(envir) || is.pairlist(envir))
+ parent.frame() else baseenv())
+ eval(substitute(expr), envir, enclos)
diff --git a/R/is.unsorted.R b/R/is.unsorted.R
new file mode 100644
index 0000000..abb6dce
--- /dev/null
+++ b/R/is.unsorted.R
@@ -0,0 +1,8 @@
+### =========================================================================
+### The is.unsorted() generic
+### -------------------------------------------------------------------------
+
+setGeneric("is.unsorted",
+ function(x, na.rm = FALSE, strictly = FALSE)
+ standardGeneric("is.unsorted"),
+ signature = "x")
diff --git a/R/normalize.R b/R/normalize.R
new file mode 100644
index 0000000..4c13ba0
--- /dev/null
+++ b/R/normalize.R
@@ -0,0 +1,8 @@
+### =========================================================================
+### The normalize() generic
+### -------------------------------------------------------------------------
+
+setGeneric("normalize",
+ function(object, ...) standardGeneric("normalize")
+)
+
diff --git a/R/normarg-utils.R b/R/normarg-utils.R
new file mode 100644
index 0000000..2bbe02b
--- /dev/null
+++ b/R/normarg-utils.R
@@ -0,0 +1,31 @@
+### =========================================================================
+### Utility functions for checking/fixing user-supplied arguments
+### -------------------------------------------------------------------------
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### For checking only.
+###
+
+isTRUEorFALSE <- function(x)
+{
+ is.logical(x) && length(x) == 1L && !is.na(x)
+}
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### Handling variadic calls
+###
+
+extraArgsAsList <- function(.valid.argnames, ...)
+{
+ args <- list(...)
+ argnames <- names(args)
+ if (length(args) != 0L
+ && (is.null(argnames) || any(argnames %in% c("", NA))))
+ stop("all extra arguments must be named")
+ if (!is.null(.valid.argnames) && !all(argnames %in% .valid.argnames))
+ stop("valid extra argument names are ",
+ paste("'", .valid.argnames, "'", sep="", collapse=", "))
+ if (anyDuplicated(argnames))
+ stop("argument names must be unique")
+ args
+}
diff --git a/R/plotMA.R b/R/plotMA.R
new file mode 100644
index 0000000..67a332b
--- /dev/null
+++ b/R/plotMA.R
@@ -0,0 +1,10 @@
+setGeneric("plotMA", function(object, ...) {
+ standardGeneric("plotMA")
+})
+
+setMethod("plotMA", signature="ANY",
+ definition = function(object, ...) {
+ msg = sprintf("Error from the generic function 'plotMA' defined in package 'BiocGenerics': no S4 method definition for argument '%s' of class '%s' was found. Did you perhaps mean calling the function 'plotMA' from another package, e.g. 'limma'? In that case, please use the syntax 'limma::plotMA'.",
+ deparse(substitute(object)), class(object))
+ stop(msg)
+ })
diff --git a/R/show-utils.R b/R/show-utils.R
new file mode 100644
index 0000000..23fee71
--- /dev/null
+++ b/R/show-utils.R
@@ -0,0 +1,60 @@
+### =========================================================================
+### Utilities for showing object components in a systematic way
+### -------------------------------------------------------------------------
+###
+
+labeledLine <-
+ function(label, els, count = TRUE, labelSep = ":", sep = " ", ellipsis = "...")
+{
+ if (count)
+ label <- paste(label, "(", length(els), ")", sep = "")
+ label <- paste(label, labelSep, sep, sep = "")
+ width <- getOption("width") - nchar(label)
+ line <- ellipsize(els, width, sep, ellipsis)
+ paste(label, line, "\n", sep = "")
+}
+
+ellipsize <-
+ function(obj, width = getOption("width"), sep = " ", ellipsis = "...")
+{
+ if (length(obj) > 2 * width)
+ obj <- c(head(obj, width), tail(obj, width))
+ str <- encodeString(obj)
+ ## get order selectSome() would print
+ half <- seq_len(ceiling(length(obj) / 2))
+ ind <- as.vector(rbind(half, length(obj) - half + 1))
+ nc <- cumsum(nchar(str[ind]) + nchar(sep)) - nchar(sep)
+ last <- findInterval(width, nc)
+ if (length(obj) > last) {
+ ## make sure ellipsis fits
+ while (last &&
+ (nc[last] + nchar(sep)*2^(last>1) + nchar(ellipsis)) > width)
+ last <- last - 1L
+ if (last == 0) ## have to truncate the first element
+ str <-
+ paste(substring(str[1L], 1, width - nchar(ellipsis)), ellipsis,
+ sep = "")
+ else if (last == 1) ## can only show the first
+ str <- c(str[1L], "...")
+ else
+ str <- selectSome(str, last + 1L)
+ }
+ paste(str, collapse = sep)
+}
+
+## taken directly from Biobase
+selectSome <- function(obj, maxToShow = 5)
+{
+ len <- length(obj)
+ if (maxToShow < 3)
+ maxToShow <- 3
+ if (len > maxToShow) {
+ maxToShow <- maxToShow - 1
+ bot <- ceiling(maxToShow/2)
+ top <- len - (maxToShow - bot - 1)
+ nms <- obj[c(1:bot, top:len)]
+ c(as.character(nms[1:bot]), "...", as.character(nms[-c(1:bot)]))
+ } else {
+ obj
+ }
+}
diff --git a/R/tapply.R b/R/tapply.R
index 79d6c9d..3d2a230 100644
--- a/R/tapply.R
+++ b/R/tapply.R
@@ -4,7 +4,7 @@
###
### Need to explicitly define this generic otherwise the implicit generic in
### package "base" would dispatch on all its arguments. Here we set dispatch
-### on the 1st arg (the 'X' arg) only!
+### on the 1st and 2nd args only!
-setGeneric("tapply", signature="X")
+setGeneric("tapply", signature=c("X", "INDEX"))
diff --git a/R/update.R b/R/update.R
new file mode 100644
index 0000000..f3f84f2
--- /dev/null
+++ b/R/update.R
@@ -0,0 +1,41 @@
+### =========================================================================
+### Efficient update behavior for S4 objects
+### -------------------------------------------------------------------------
+###
+### 'updateS4' is essentially a more efficient initialize for (value) S4 objects.
+
+unsafe_updateS4 <- function(object, ..., .slotList = list()) {
+ valid_argnames <- slotNames(object)
+ args <- extraArgsAsList(valid_argnames, ...)
+ firstTime <- TRUE
+ listUpdate <- function(object, l) {
+ for (nm in names(l)) {
+ ## Too risky! identical() is not reliable enough e.g. with objects
+ ## that contain external pointers. For example, DNAStringSet("A") and
+ ## DNAStringSet("T") are considered to be identical! identical() needs
+ ## to be fixed first.
+ ##if (identical(slot(object, nm), l[[nm]]))
+ ## next
+ if (firstTime) {
+ ## Triggers a copy.
+ slot(object, nm, check=FALSE) <- l[[nm]]
+ firstTime <<- FALSE
+ } else {
+ ## In-place modification (i.e. no copy).
+ `slot<-`(object, nm, check=FALSE, l[[nm]])
+ }
+ }
+ object
+ }
+ listUpdate(listUpdate(object, args), .slotList)
+}
+
+updateS4 <- function(object, ..., check = TRUE) {
+ if (!isTRUEorFALSE(check))
+ stop("'check' must be TRUE or FALSE")
+ object <- unsafe_updateS4(object, ...)
+ if (check) {
+ validObject(object)
+ }
+ object
+}
diff --git a/TODO b/TODO
index 681baf0..3c03858 100644
--- a/TODO
+++ b/TODO
@@ -3,10 +3,6 @@ o Functions defined in base R that would need to be explicitly promoted
made generics by the IRanges package):
From package base:
- - append(): implicit generic dispatches on (x, values, after).
- Explicit generic should dispatch on (x, values) only (or maybe just x?)
- - as.vector(): implicit generic dispatches on (x, mode).
- Explicit generic should dispatch on (x) only.
- is.unsorted(): implicit generic dispatches on (x, na.rm, strictly).
Explicit generic should dispatch on (x) only.
- split(): implicit generic dispatches on (x, f, drop).
diff --git a/man/BiocGenerics-package.Rd b/man/BiocGenerics-package.Rd
index ea9f8b2..ddbb75f 100644
--- a/man/BiocGenerics-package.Rd
+++ b/man/BiocGenerics-package.Rd
@@ -21,8 +21,12 @@
Generics for functions defined in package base:
\itemize{
+ \item \code{BiocGenerics::\link[BiocGenerics]{append}}
+
\item \code{BiocGenerics::\link[BiocGenerics]{as.data.frame}}
+ \item \code{BiocGenerics::\link[BiocGenerics]{as.vector}}
+
\item \code{BiocGenerics::\link[BiocGenerics]{cbind}},
\code{BiocGenerics::\link[BiocGenerics]{rbind}}
@@ -130,6 +134,8 @@
\item \code{\link[BiocGenerics]{combine}}
+ \item \code{\link[BiocGenerics]{normalize}}
+
\item \code{\link[BiocGenerics]{strand}},
\code{\link[BiocGenerics]{strand<-}}
@@ -166,14 +172,16 @@
\author{The Bioconductor Dev Team}
\seealso{
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \itemize{
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \code{\link[methods]{setGeneric}} and \code{\link[methods]{setMethod}}
- for defining generics and methods.
+ \item \code{\link[methods]{setGeneric}} and
+ \code{\link[methods]{setMethod}} for defining generics and methods.
+ }
}
\examples{
diff --git a/man/Extremes.Rd b/man/Extremes.Rd
index cfae8b4..944b697 100644
--- a/man/Extremes.Rd
+++ b/man/Extremes.Rd
@@ -32,7 +32,7 @@ pmin.int(..., na.rm=FALSE)
\arguments{
\item{...}{
- One or more vector-like or matrix-like R objects.
+ One or more vector-like or matrix-like objects.
}
\item{na.rm}{
See \code{?base::\link[base]{pmax}} for a description of
@@ -49,21 +49,23 @@ pmin.int(..., na.rm=FALSE)
}
\seealso{
- \code{base::\link[base]{pmax}} for the default \code{pmax}, \code{pmin},
- \code{pmax.int} and \code{pmin.int} methods.
+ \itemize{
+ \item \code{base::\link[base]{pmax}} for the default \code{pmax},
+ \code{pmin}, \code{pmax.int} and \code{pmin.int} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{pmax,Rle-method} in the IRanges package
- for an example of a specific \code{pmax} method (defined for
- \link[IRanges]{Rle} objects).
+ \item \link[IRanges]{pmax,Rle-method} in the IRanges package
+ for an example of a specific \code{pmax} method (defined for
+ \link[IRanges]{Rle} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/annotation.Rd b/man/annotation.Rd
index 2b6d038..9073eea 100644
--- a/man/annotation.Rd
+++ b/man/annotation.Rd
@@ -27,18 +27,20 @@ annotation(object, ...) <- value
}
\seealso{
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \itemize{
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[Biobase]{annotation,eSet-method} in the Biobase
- package for an example of a specific \code{annotation} method (defined
- for \link[Biobase]{eSet} objects).
+ \item \link[Biobase]{annotation,eSet-method} in the Biobase package
+ for an example of a specific \code{annotation} method (defined for
+ \link[Biobase]{eSet} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/append.Rd b/man/append.Rd
new file mode 100644
index 0000000..9e6e36a
--- /dev/null
+++ b/man/append.Rd
@@ -0,0 +1,72 @@
+\name{append}
+
+\alias{append}
+
+\title{Append elements to a vector-like object}
+
+\description{
+ Append (or insert) elements to (in) a vector-like object.
+
+ NOTE: This man page is for the \code{append} \emph{S4 generic function}
+ defined in the BiocGenerics package.
+ See \code{?base::\link[base]{append}} for the default method
+ (defined in the base package).
+ Bioconductor packages can define specific methods for objects
+ (typically vector-like or data-frame-like) not supported by the
+ default method.
+}
+
+\usage{
+append(x, values, after=length(x))
+}
+
+\arguments{
+ \item{x}{
+ The vector-like object to be modified.
+ }
+ \item{values}{
+ The vector-like object containing the values to be appended to \code{x}.
+ \code{values} would typically be of the same class as \code{x}, but not
+ necessarily.
+ }
+ \item{after}{
+ A subscript, after which the values are to be appended.
+ }
+}
+
+\value{
+ See \code{?base::\link[base]{append}} for the value returned by the
+ default method.
+
+ Specific methods defined in Bioconductor packages will typically
+ return an object of the same class as \code{x} and of length
+ \code{length(x) + length(values)}.
+}
+
+\seealso{
+ \itemize{
+ \item \code{base::\link[base]{append}} for the default \code{append}
+ method.
+
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
+
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
+
+ \item \link[IRanges]{append,Vector,Vector-method} in the IRanges package
+ for an example of a specific \code{append} method (defined for
+ \link[IRanges]{Vector} objects).
+
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
+}
+
+\examples{
+append # note the dispatch on the 'x' and 'values' args only
+showMethods("append")
+selectMethod("append", c("ANY", "ANY")) # the default method
+}
+
+\keyword{methods}
diff --git a/man/as.data.frame.Rd b/man/as.data.frame.Rd
index 109202b..55e1f3e 100644
--- a/man/as.data.frame.Rd
+++ b/man/as.data.frame.Rd
@@ -2,7 +2,7 @@
\alias{as.data.frame}
-\title{Coerce to a data frame}
+\title{Coerce an object into a data frame}
\description{
Function to coerce to a data frame, if possible.
@@ -21,7 +21,7 @@ as.data.frame(x, row.names=NULL, optional=FALSE, ...)
\arguments{
\item{x}{
- Any R object.
+ The object to coerce.
}
\item{row.names, optional, ...}{
See \code{?base::\link[base]{as.data.frame}} for a description of
@@ -40,23 +40,25 @@ as.data.frame(x, row.names=NULL, optional=FALSE, ...)
}
\seealso{
- \code{base::\link[base]{as.data.frame}} for the default
- \code{as.data.frame} method.
+ \itemize{
+ \item \code{base::\link[base]{as.data.frame}} for the default
+ \code{as.data.frame} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{as.data.frame,Ranges-method} and
- \link[IRanges]{as.data.frame,DataFrame-method} in the IRanges package
- for examples of specific \code{as.data.frame} methods (defined for
- \link[IRanges]{Ranges} and \link[IRanges]{DataFrame} objects,
- respectively).
+ \item \link[IRanges]{as.data.frame,Ranges-method} and
+ \link[IRanges]{as.data.frame,DataFrame-method} in the IRanges package
+ for examples of specific \code{as.data.frame} methods (defined for
+ \link[IRanges]{Ranges} and \link[IRanges]{DataFrame} objects,
+ respectively).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/as.vector.Rd b/man/as.vector.Rd
new file mode 100644
index 0000000..763a4c8
--- /dev/null
+++ b/man/as.vector.Rd
@@ -0,0 +1,73 @@
+\name{as.vector}
+
+\alias{as.vector}
+
+\title{Coerce an object into a vector}
+
+\description{
+ Attempt to coerce an object into a vector of the specified mode.
+ If the mode is not specified, attempt to coerce to whichever vector
+ mode is considered more appropriate for the class of the supplied
+ object.
+
+ NOTE: This man page is for the \code{as.vector}
+ \emph{S4 generic function} defined in the BiocGenerics package.
+ See \code{?base::\link[base]{as.vector}} for the default method
+ (defined in the base package).
+ Bioconductor packages can define specific methods for objects
+ not supported by the default method.
+}
+
+\usage{
+as.vector(x, mode="any")
+}
+
+\arguments{
+ \item{x}{
+ The object to coerce.
+ }
+ \item{mode}{
+ See \code{?base::\link[base]{as.vector}} for a description of
+ this argument.
+ }
+}
+
+\value{
+ A vector.
+
+ See \code{?base::\link[base]{as.vector}} for the value returned
+ by the default method.
+
+ Specific methods defined in Bioconductor packages should
+ behave as consistently as possible with the default method.
+}
+
+\seealso{
+ \itemize{
+ \item \code{base::\link[base]{as.vector}} for the default
+ \code{as.vector} method.
+
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
+
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
+
+ \item \link[IRanges]{as.vector,Rle-method} and
+ \link[IRanges]{as.vector,AtomicList-method} in the IRanges package
+ for examples of specific \code{as.vector} methods (defined for
+ \link[IRanges]{Rle} and \link[IRanges]{AtomicList} objects,
+ respectively).
+
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
+}
+
+\examples{
+as.vector # note the dispatch on the 'x' arg only
+showMethods("as.vector")
+selectMethod("as.vector", "ANY") # the default method
+}
+
+\keyword{methods}
diff --git a/man/boxplot.Rd b/man/boxplot.Rd
index aa425d0..4a1cbb0 100644
--- a/man/boxplot.Rd
+++ b/man/boxplot.Rd
@@ -34,21 +34,23 @@ boxplot(x, ...)
}
\seealso{
- \code{graphics::\link[graphics]{boxplot}} for the default \code{boxplot}
- method.
+ \itemize{
+ \item \code{graphics::\link[graphics]{boxplot}} for the default
+ \code{boxplot} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[oligo]{boxplot,FeatureSet-method} in the oligo package
- for an example of a specific \code{boxplot} method (defined for
- \link[oligoClasses]{FeatureSet} objects).
+ \item \link[oligo]{boxplot,FeatureSet-method} in the oligo package
+ for an example of a specific \code{boxplot} method (defined for
+ \link[oligoClasses]{FeatureSet} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/cbind.Rd b/man/cbind.Rd
index 6494c87..bfdf9b8 100644
--- a/man/cbind.Rd
+++ b/man/cbind.Rd
@@ -3,11 +3,11 @@
\alias{cbind}
\alias{rbind}
-\title{Combine R objects by rows or columns}
+\title{Combine objects by rows or columns}
\description{
- \code{cbind} and \code{rbind} take a sequence of R objects arguments
- and combine them by columns or rows, respectively.
+ \code{cbind} and \code{rbind} take one or more objects and combine them
+ by columns or rows, respectively.
NOTE: This man page is for the \code{cbind} and \code{rbind}
\emph{S4 generic functions} defined in the BiocGenerics package.
@@ -25,7 +25,7 @@ rbind(..., deparse.level=1)
\arguments{
\item{...}{
- One or more vector-like or matrix-like R objects. These can be given as
+ One or more vector-like or matrix-like objects. These can be given as
named arguments.
}
\item{deparse.level}{
@@ -43,21 +43,23 @@ rbind(..., deparse.level=1)
}
\seealso{
- \code{base::\link[base]{cbind}} for the default \code{cbind} and
- \code{rbind} methods.
+ \itemize{
+ \item \code{base::\link[base]{cbind}} for the default \code{cbind} and
+ \code{rbind} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{cbind,DataFrame-method} in the IRanges package
- for an example of a specific \code{cbind} method (defined for
- \link[IRanges]{DataFrame} objects).
+ \item \link[IRanges]{cbind,DataFrame-method} in the IRanges package
+ for an example of a specific \code{cbind} method (defined for
+ \link[IRanges]{DataFrame} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/clusterApply.Rd b/man/clusterApply.Rd
index cd97606..833d882 100644
--- a/man/clusterApply.Rd
+++ b/man/clusterApply.Rd
@@ -86,16 +86,19 @@ parSapplyLB(cl=NULL, X, FUN, ..., simplify=TRUE, USE.NAMES=TRUE)
}
\seealso{
- \code{parallel::\link[parallel]{clusterApply}} for the default methods.
+ \itemize{
+ \item \code{parallel::\link[parallel]{clusterApply}} for the default
+ methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/combine.Rd b/man/combine.Rd
index c754470..0ba2a0d 100644
--- a/man/combine.Rd
+++ b/man/combine.Rd
@@ -80,23 +80,25 @@ combine(x, y, ...)
\author{Biocore}
\seealso{
- \link[Biobase]{combine,AnnotatedDataFrame,AnnotatedDataFrame-method},
- \link[Biobase]{combine,AssayData,AssayData-method},
- \link[Biobase]{combine,MIAME,MIAME-method},
- and \link[Biobase]{combine,eSet,eSet-method} in the Biobase package
- for additional \code{combine} methods.
+ \itemize{
+ \item \link[Biobase]{combine,AnnotatedDataFrame,AnnotatedDataFrame-method},
+ \link[Biobase]{combine,AssayData,AssayData-method},
+ \link[Biobase]{combine,MIAME,MIAME-method},
+ and \link[Biobase]{combine,eSet,eSet-method} in the Biobase package
+ for additional \code{combine} methods.
- \code{\link{merge}} for merging two data frames (or data.frame-like)
- R objects.
+ \item \code{\link{merge}} for merging two data frames (or data.frame-like)
+ objects.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/density.Rd b/man/density.Rd
index c9dace8..747af78 100644
--- a/man/density.Rd
+++ b/man/density.Rd
@@ -35,21 +35,23 @@ density(x, ...)
}
\seealso{
- \code{stats::\link[stats]{density}} for the default \code{density}
- method.
+ \itemize{
+ \item \code{stats::\link[stats]{density}} for the default \code{density}
+ method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[flowClust]{density,flowClust-method} in the flowClust package
- for an example of a specific \code{density} method (defined for
- \link[flowClust]{flowClust} objects).
+ \item \link[flowClust]{density,flowClust-method} in the flowClust package
+ for an example of a specific \code{density} method (defined for
+ \link[flowClust]{flowClust} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/dge.Rd b/man/dge.Rd
new file mode 100644
index 0000000..4061fd9
--- /dev/null
+++ b/man/dge.Rd
@@ -0,0 +1,51 @@
+\name{dge}
+\alias{conditions}
+\alias{conditions<-}
+\alias{design}
+\alias{design<-}
+\alias{counts}
+\alias{counts<-}
+\alias{dispTable}
+\alias{dispTable<-}
+\alias{sizeFactors}
+\alias{sizeFactors<-}
+\alias{estimateSizeFactors}
+\alias{estimateDispersions}
+\alias{plotDispEsts}
+
+\title{Accessors and generic functions used in the context of count datasets}
+
+\description{These generic functions provide basic interfaces to operations on
+and data access to count datasets.}
+
+\usage{
+counts(object, ...)
+counts(object, ...) <- value
+dispTable(object, ...)
+dispTable(object, ...) <- value
+sizeFactors(object, ...)
+sizeFactors(object, ...) <- value
+conditions(object, ...)
+conditions(object, ...) <- value
+design(object, ...)
+design(object, ...) <- value
+estimateSizeFactors(object, ...)
+estimateDispersions(object, ...)
+plotDispEsts(object, ...)
+}
+
+\arguments{
+ \item{object}{Object of class for which methods are defined, e.g.,
+ \code{CountDataSet}, \code{DESeqSummarizedExperiment} or \code{ExonCountSet}.}
+ \item{value}{Value to be assigned to corresponding components of
+ \code{object}; supported types depend on method implementation.}
+ \item{...}{Further arguments, perhaps used by metohds}
+}
+
+\details{For the details, please consult the manual pages of the
+ methods in the \code{DESeq}, \code{DESeq2}, and \code{DEXSeq} packages and the package
+ vignettes.}
+
+\author{W. Huber, S. Anders}
+
+\keyword{manip}
diff --git a/man/duplicated.Rd b/man/duplicated.Rd
index e939aba..95a12c4 100644
--- a/man/duplicated.Rd
+++ b/man/duplicated.Rd
@@ -6,7 +6,7 @@
\title{Determine duplicate elements}
\description{
- Determines which elements of a vector-like or data-frame-like R object
+ Determines which elements of a vector-like or data-frame-like object
are duplicates of elements with smaller subscripts, and returns a
logical vector indicating which elements (rows) are duplicates.
@@ -26,7 +26,7 @@ anyDuplicated(x, incomparables=FALSE, ...)
\arguments{
\item{x}{
- A vector-like or data-frame-like R object.
+ A vector-like or data-frame-like object.
}
\item{incomparables, ...}{
See \code{?base::\link[base]{duplicated}} for a description of
@@ -59,21 +59,23 @@ anyDuplicated(x, incomparables=FALSE, ...)
}
\seealso{
- \code{base::\link[base]{duplicated}} for the default \code{duplicated}
- and \code{anyDuplicated} methods.
+ \itemize{
+ \item \code{base::\link[base]{duplicated}} for the default
+ \code{duplicated} and \code{anyDuplicated} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{duplicated,Ranges-method} in the IRanges package
- for an example of a specific \code{duplicated} method (defined for
- \link[IRanges]{Ranges} objects).
+ \item \link[IRanges]{duplicated,Ranges-method} in the IRanges package
+ for an example of a specific \code{duplicated} method (defined for
+ \link[IRanges]{Ranges} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/eval.Rd b/man/eval.Rd
index 0b1479d..e5d5a27 100644
--- a/man/eval.Rd
+++ b/man/eval.Rd
@@ -49,21 +49,24 @@ eval(expr, envir=parent.frame(),
}
\seealso{
- \code{base::\link[base]{eval}} for the default \code{eval} method.
+ \itemize{
+ \item \code{base::\link[base]{eval}} for the default \code{eval} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{eval,expression,List-method} in the IRanges
- package for an example of a specific \code{eval} method (defined
- for when the \code{expr} and \code{envir} arguments are an
- \link[base]{expression} and a \link[IRanges]{List} object, respectively).
+ \item \link[IRanges]{eval,expression,List-method} in the IRanges package
+ for an example of a specific \code{eval} method (defined for
+ when the \code{expr} and \code{envir} arguments are an
+ \link[base]{expression} and a \link[IRanges]{List} object,
+ respectively).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/evalq.Rd b/man/evalq.Rd
new file mode 100644
index 0000000..94bc538
--- /dev/null
+++ b/man/evalq.Rd
@@ -0,0 +1,51 @@
+\name{evalq}
+
+\alias{evalq}
+
+\title{Evaluate an (unevaluated) expression}
+
+\description{
+ \code{evalq} evaluates an R expression (the quoted form of its first
+ argument) in a specified environment.
+
+ NOTE: This man page is for the \code{evalq} wrapper defined in the
+ BiocGenerics package. See \code{?base::\link[base]{evalq}} for the
+ function defined in the base package. This wrapper correctly delegates
+ to the \code{eval} generic, rather than
+ \code{base::\link[base]{eval}}.
+}
+
+\usage{
+evalq(expr, envir=parent.frame(),
+ enclos=if (is.list(envir) || is.pairlist(envir))
+ parent.frame() else baseenv())
+}
+
+\arguments{
+ \item{expr}{
+ Quoted to form the expression that is evaluated.
+ }
+ \item{envir}{
+ The \emph{environment} in which \code{expr} is to be evaluated.
+ May be any object supported by methods on the \code{\link{eval}}
+ generic.
+ }
+ \item{enclos}{
+ See \code{?base::\link[base]{evalq}} for a description of
+ this argument.
+ }
+}
+
+\value{
+ See \code{?base::\link[base]{evalq}}.
+}
+
+\seealso{
+ \itemize{
+ \item \code{base::\link[base]{evalq}} for the base \code{evalq} function.
+ }
+}
+
+\examples{
+evalq # note just a copy of the original evalq
+}
diff --git a/man/funprog.Rd b/man/funprog.Rd
index 5413577..f733572 100644
--- a/man/funprog.Rd
+++ b/man/funprog.Rd
@@ -11,14 +11,14 @@
\description{
\code{Reduce} uses a binary function to successively combine the
- elements of a given list-like or vector-like R object and a possibly
+ elements of a given list-like or vector-like object and a possibly
given initial value.
\code{Filter} extracts the elements of a list-like or vector-like
- R object for which a predicate (logical) function gives true.
+ object for which a predicate (logical) function gives true.
\code{Find} and \code{Position} give the first or last such element
and its position in the object, respectively.
\code{Map} applies a function to the corresponding elements of given
- list-like or vector-like R objects.
+ list-like or vector-like objects.
NOTE: This man page is for the \code{Reduce}, \code{Filter},
\code{Find}, \code{Map} and \code{Position} \emph{S4 generic functions}
@@ -44,10 +44,10 @@ Position(f, x, right=FALSE, nomatch=NA_integer_)
these arguments.
}
\item{x}{
- A list-like or vector-like R object.
+ A list-like or vector-like object.
}
\item{...}{
- One or more list-like or vector-like R objects.
+ One or more list-like or vector-like objects.
}
}
@@ -60,21 +60,23 @@ Position(f, x, right=FALSE, nomatch=NA_integer_)
}
\seealso{
- \code{base::\link[base]{Reduce}} for the default \code{Reduce},
- \code{Filter}, \code{Find}, \code{Map} and \code{Position} methods.
+ \itemize{
+ \item \code{base::\link[base]{Reduce}} for the default \code{Reduce},
+ \code{Filter}, \code{Find}, \code{Map} and \code{Position} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{Reduce,List-method} in the IRanges package
- for an example of a specific \code{Reduce} method (defined for
- \link[IRanges]{List} objects).
+ \item \link[IRanges]{Reduce,List-method} in the IRanges package
+ for an example of a specific \code{Reduce} method (defined for
+ \link[IRanges]{List} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/get.Rd b/man/get.Rd
index ffa21cc..df492e5 100644
--- a/man/get.Rd
+++ b/man/get.Rd
@@ -6,7 +6,7 @@
\title{Return the value of a named object}
\description{
- Search for an R object with a given name and return it.
+ Search for an object with a given name and return it.
NOTE: This man page is for the \code{get} and \code{mget} \emph{S4 generic
functions} defined in the BiocGenerics package.
@@ -54,21 +54,23 @@ mget(x, envir, mode="any", ifnotfound, inherits=FALSE)
}
\seealso{
- \code{base::\link[base]{get}} for the default \code{get} and \code{mget}
- methods.
+ \itemize{
+ \item \code{base::\link[base]{get}} for the default \code{get} and
+ \code{mget} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[AnnotationDbi]{get,ANY,Bimap,missing-method} in the
- AnnotationDbi package for an example of a specific \code{get} method
- (defined for \link[AnnotationDbi]{Bimap} objects).
+ \item \link[AnnotationDbi]{get,ANY,Bimap,missing-method} in the
+ AnnotationDbi package for an example of a specific \code{get}
+ method (defined for \link[AnnotationDbi]{Bimap} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/image.Rd b/man/image.Rd
index bd58dac..63e7256 100644
--- a/man/image.Rd
+++ b/man/image.Rd
@@ -36,21 +36,23 @@ image(x, ...)
}
\seealso{
- \code{graphics::\link[graphics]{image}} for the default \code{image}
- method.
+ \itemize{
+ \item \code{graphics::\link[graphics]{image}} for the default \code{image}
+ method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[oligo]{image,FeatureSet-method} in the oligo package
- for an example of a specific \code{image} method (defined for
- \link[oligoClasses]{FeatureSet} objects).
+ \item \link[oligo]{image,FeatureSet-method} in the oligo package
+ for an example of a specific \code{image} method (defined for
+ \link[oligoClasses]{FeatureSet} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/is.unsorted.Rd b/man/is.unsorted.Rd
new file mode 100644
index 0000000..3a8fab8
--- /dev/null
+++ b/man/is.unsorted.Rd
@@ -0,0 +1,80 @@
+\name{is.unsorted}
+
+\alias{is.unsorted}
+
+\title{Test if an Object is Not Sorted}
+
+\description{
+ Test if an object is not sorted, without the cost of sorting it.
+
+ NOTE: This man page is for the \code{is.unsorted}
+ \emph{S4 generic function} defined in the BiocGenerics package.
+ See \code{?base::\link[base]{is.unsorted}} for the default method
+ (defined in the base package).
+ Bioconductor packages can define specific methods for objects
+ not supported by the default method.
+}
+
+\usage{
+is.unsorted(x, na.rm = FALSE, strictly = FALSE)
+}
+
+\arguments{
+ \item{x}{
+ A vector-like object.
+ }
+ \item{na.rm, strictly}{
+ See \code{?base::\link[base]{is.unsorted}} for a description of
+ these arguments.
+ }
+}
+
+\value{
+ See \code{?base::\link[base]{is.unsorted}} for the value returned
+ by the default method.
+
+ Specific methods defined in Bioconductor packages should
+ behave as consistently as possible with the default method.
+}
+
+\note{
+ TO DEVELOPPERS:
+
+ See note in \code{?BiocGenerics::\link[BiocGenerics]{order}}
+ about "stable" order.
+
+ \code{\link[BiocGenerics]{order}}, \code{\link[BiocGenerics]{sort}},
+ and \code{\link[BiocGenerics]{rank}} methods for specific vector-like
+ objects should adhere to the same underlying order that should be
+ conceptually defined as a binary relation on the set of all possible
+ vector values. For completeness, this binary relation should also be
+ incarnated by a \link{<=} method.
+}
+
+\seealso{
+ \itemize{
+ \item \code{base::\link[base]{is.unsorted}} for the default
+ \code{is.unsorted} method.
+
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
+
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
+
+ \item \link[IRanges]{is.unsorted,Rle-method} in the IRanges package
+ for an example of a specific \code{is.unsorted} method (defined for
+ \link[IRanges]{Rle} objects).
+
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
+}
+
+\examples{
+is.unsorted # note the dispatch on the 'x' arg only
+showMethods("is.unsorted")
+selectMethod("is.unsorted", "ANY") # the default method
+}
+
+\keyword{methods}
diff --git a/man/lapply.Rd b/man/lapply.Rd
index eb2dea4..615d346 100644
--- a/man/lapply.Rd
+++ b/man/lapply.Rd
@@ -3,7 +3,7 @@
\alias{lapply}
\alias{sapply}
-\title{Apply a function over a list-like or vector-like R object}
+\title{Apply a function over a list-like or vector-like object}
\description{
\code{lapply} returns a list of the same length as \code{X}, each
@@ -32,7 +32,7 @@ sapply(X, FUN, ..., simplify=TRUE, USE.NAMES=TRUE)
\arguments{
\item{X}{
- A list-like or vector-like R object.
+ A list-like or vector-like object.
}
\item{FUN, ..., simplify, USE.NAMES}{
See \code{?base::\link[base]{lapply}} for a description of
@@ -51,21 +51,23 @@ sapply(X, FUN, ..., simplify=TRUE, USE.NAMES=TRUE)
}
\seealso{
- \code{base::\link[base]{lapply}} for the default \code{lapply} and
- \code{sapply} methods.
+ \itemize{
+ \item \code{base::\link[base]{lapply}} for the default \code{lapply} and
+ \code{sapply} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{lapply,List-method} in the IRanges package
- for an example of a specific \code{lapply} method (defined for
- \link[IRanges]{List} objects).
+ \item \link[IRanges]{lapply,List-method} in the IRanges package
+ for an example of a specific \code{lapply} method (defined for
+ \link[IRanges]{List} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/mapply.Rd b/man/mapply.Rd
index 79098b2..441ef0c 100644
--- a/man/mapply.Rd
+++ b/man/mapply.Rd
@@ -30,7 +30,7 @@ mapply(FUN, ..., MoreArgs=NULL, SIMPLIFY=TRUE, USE.NAMES=TRUE)
these arguments.
}
\item{...}{
- One or more list-like or vector-like R objects of strictly
+ One or more list-like or vector-like objects of strictly
positive length, or all of zero length.
}
}
@@ -44,20 +44,23 @@ mapply(FUN, ..., MoreArgs=NULL, SIMPLIFY=TRUE, USE.NAMES=TRUE)
}
\seealso{
- \code{base::\link[base]{mapply}} for the default \code{mapply} method.
+ \itemize{
+ \item \code{base::\link[base]{mapply}} for the default \code{mapply}
+ method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{mapply,List-method} in the IRanges package
- for an example of a specific \code{mapply} method (defined for
- \link[IRanges]{List} objects).
+ \item \link[IRanges]{mapply,List-method} in the IRanges package
+ for an example of a specific \code{mapply} method (defined for
+ \link[IRanges]{List} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/match.Rd b/man/match.Rd
index f96b947..bd9c8c7 100644
--- a/man/match.Rd
+++ b/man/match.Rd
@@ -22,7 +22,7 @@ match(x, table, nomatch=NA_integer_, incomparables=NULL, ...)
\arguments{
\item{x, table}{
- Vector-like R objects (typically of the same class, but not necessarily).
+ Vector-like objects (typically of the same class, but not necessarily).
}
\item{nomatch, incomparables}{
See \code{?base::\link[base]{match}} for a description of
@@ -52,20 +52,22 @@ match(x, table, nomatch=NA_integer_, incomparables=NULL, ...)
}
\seealso{
- \code{base::\link[base]{match}} for the default \code{match} method.
+ \itemize{
+ \item \code{base::\link[base]{match}} for the default \code{match} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{match,Hits,Hits-method} in the IRanges
- package for an example of a specific \code{match} method (defined for
- \link[IRanges]{Hits} objects).
+ \item \link[IRanges]{match,Hits,Hits-method} in the IRanges package
+ for an example of a specific \code{match} method (defined for
+ \link[IRanges]{Hits} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/normalize.Rd b/man/normalize.Rd
new file mode 100644
index 0000000..922b6b1
--- /dev/null
+++ b/man/normalize.Rd
@@ -0,0 +1,61 @@
+\name{normalize}
+
+\alias{normalize}
+
+\title{Normalize an object}
+
+\description{
+ A generic function which normalizes an object containing microarray data
+ or other data.
+ Normalization is intended to remove from the intensity measures any
+ systematic trends which arise from the microarray technology rather than
+ from differences between the probes or between the target RNA samples
+ hybridized to the arrays.
+}
+
+\usage{
+normalize(object, ...)
+}
+
+\arguments{
+ \item{object}{
+ A data object, typically containing microarray data.
+ }
+ \item{...}{
+ Additional arguments, for use in specific methods.
+ }
+}
+
+\value{
+ An object containing the normalized data.
+}
+
+\seealso{
+ \itemize{
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
+
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
+
+ \item \link[affy]{normalize,AffyBatch-method} in the affy package
+ and \link[oligo]{normalize,FeatureSet-method} in the oligo package
+ for examples of specific \code{normalize} methods (defined for
+ \link[affy]{AffyBatch} and \link[oligoClasses]{FeatureSet} objects,
+ respectively).
+
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
+}
+
+\examples{
+normalize
+showMethods("normalize")
+
+library(affy)
+showMethods("normalize")
+selectMethod("normalize", "AffyBatch")
+}
+
+\keyword{methods}
diff --git a/man/nrow.Rd b/man/nrow.Rd
index 21fe274..2127448 100644
--- a/man/nrow.Rd
+++ b/man/nrow.Rd
@@ -8,7 +8,7 @@
\title{The number of rows/columns of an array-like object}
\description{
- Return the number of rows or columns present in an array-like R object.
+ Return the number of rows or columns present in an array-like object.
NOTE: This man page is for the \code{nrow}, \code{ncol}, \code{NROW} and
\code{NCOL} \emph{S4 generic functions} defined in the BiocGenerics package.
@@ -27,7 +27,7 @@ NCOL(x)
\arguments{
\item{x}{
- A matrix- or array-like R object.
+ A matrix- or array-like object.
}
}
@@ -39,21 +39,23 @@ NCOL(x)
}
\seealso{
- \code{base::\link[base]{nrow}} for the default \code{nrow}, \code{ncol},
- \code{NROW} and \code{NCOL} methods.
+ \itemize{
+ \item \code{base::\link[base]{nrow}} for the default \code{nrow},
+ \code{ncol}, \code{NROW} and \code{NCOL} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{nrow,DataFrame-method} in the IRanges package
- for an example of a specific \code{nrow} method (defined for
- \link[IRanges]{DataFrame} objects).
+ \item \link[IRanges]{nrow,DataFrame-method} in the IRanges package
+ for an example of a specific \code{nrow} method (defined for
+ \link[IRanges]{DataFrame} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/order.Rd b/man/order.Rd
index 5829d3c..d8d1801 100644
--- a/man/order.Rd
+++ b/man/order.Rd
@@ -23,7 +23,7 @@ order(..., na.last=TRUE, decreasing=FALSE)
\arguments{
\item{...}{
- One or more vector-like R objects, all of the same length.
+ One or more vector-like objects, all of the same length.
}
\item{na.last, decreasing}{
See \code{?base::\link[base]{order}} for a description of
@@ -64,20 +64,22 @@ order(..., na.last=TRUE, decreasing=FALSE)
}
\seealso{
- \code{base::\link[base]{order}} for the default \code{order} method.
+ \itemize{
+ \item \code{base::\link[base]{order}} for the default \code{order} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{order,Ranges-method} in the IRanges package
- for an example of a specific \code{order} method (defined for
- \link[IRanges]{Ranges} objects).
+ \item \link[IRanges]{order,Ranges-method} in the IRanges package
+ for an example of a specific \code{order} method (defined for
+ \link[IRanges]{Ranges} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/paste.Rd b/man/paste.Rd
index c5cfa00..8ffcab1 100644
--- a/man/paste.Rd
+++ b/man/paste.Rd
@@ -5,7 +5,7 @@
\title{Concatenate strings}
\description{
- \code{paste} concatenates vectors of strings or vector-like R
+ \code{paste} concatenates vectors of strings or vector-like
objects containing strings.
NOTE: This man page is for the \code{paste} \emph{S4 generic function}
@@ -23,7 +23,7 @@ paste(..., sep=" ", collapse=NULL)
\arguments{
\item{...}{
- One or more vector-like R objects containing strings.
+ One or more vector-like objects containing strings.
}
\item{sep, collapse}{
See \code{?base::\link[base]{paste}} for a description of
@@ -40,20 +40,22 @@ paste(..., sep=" ", collapse=NULL)
}
\seealso{
- \code{base::\link[base]{paste}} for the default \code{paste} method.
+ \itemize{
+ \item \code{base::\link[base]{paste}} for the default \code{paste} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{paste,Rle-method} in the IRanges package
- for an example of a specific \code{paste} method (defined for
- \link[IRanges]{Rle} objects).
+ \item \link[IRanges]{paste,Rle-method} in the IRanges package
+ for an example of a specific \code{paste} method (defined for
+ \link[IRanges]{Rle} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/plotMA.Rd b/man/plotMA.Rd
new file mode 100644
index 0000000..a44a4cc
--- /dev/null
+++ b/man/plotMA.Rd
@@ -0,0 +1,55 @@
+\name{plotMA}
+
+\alias{plotMA}
+\alias{plotMA,ANY-method}
+
+\title{MA-plot: plot differences versus averages for high-throughput data}
+
+\description{
+ A generic function which produces an MA-plot for an object containing microarray, RNA-Seq
+ or other data.
+}
+
+\usage{
+plotMA(object, ...)
+}
+
+\arguments{
+ \item{object}{
+ A data object, typically containing count values from an RNA-Seq experiment or microarray intensity values.
+ }
+ \item{...}{
+ Additional arguments, for use in specific methods.
+ }
+}
+
+\value{
+ Undefined. The function exists for its side effect, producing a plot.
+}
+
+\seealso{
+ \itemize{
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
+
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
+
+ \item \code{\link[limma]{plotMA}} in the \code{limma} package
+ for a function with the same name that is not dispatched through this generic function.
+
+ \item \code{\link{BiocGenerics}} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
+}
+
+\examples{
+showMethods("plotMA")
+
+suppressWarnings(
+ if(require("DESeq2"))
+ example("plotMA", package="DESeq2", local=TRUE)
+)
+}
+
+\keyword{methods}
diff --git a/man/rank.Rd b/man/rank.Rd
index 3a85bec..61d2c34 100644
--- a/man/rank.Rd
+++ b/man/rank.Rd
@@ -23,7 +23,7 @@ rank(x, na.last=TRUE,
\arguments{
\item{x}{
- A vector-like R object.
+ A vector-like object.
}
\item{na.last, ties.method}{
See \code{?base::\link[base]{rank}} for a description of
@@ -54,21 +54,22 @@ rank(x, na.last=TRUE,
}
\seealso{
- \code{base::\link[base]{rank}} for the default
- \code{rank} method.
+ \itemize{
+ \item \code{base::\link[base]{rank}} for the default \code{rank} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{rank,Vector-method} in the IRanges package
- for an example of a specific \code{rank} method (defined for
- \link[IRanges]{Vector} objects).
+ \item \link[IRanges]{rank,Ranges-method} in the IRanges package
+ for an example of a specific \code{rank} method (defined for
+ \link[IRanges]{Ranges} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/rep.Rd b/man/rep.Rd
index 7c6b0e5..55a2517 100644
--- a/man/rep.Rd
+++ b/man/rep.Rd
@@ -2,7 +2,7 @@
\alias{rep.int}
-\title{Replicate elements of a vector-like R object}
+\title{Replicate elements of a vector-like object}
\description{
\code{rep.int} replicates the elements in \code{x}.
@@ -24,7 +24,7 @@ rep.int(x, ...)
\arguments{
\item{x}{
- R object (typically vector-like).
+ The object to replicate (typically vector-like).
}
\item{...}{
Additional arguments, for use in specific \code{rep.int} methods.
@@ -40,21 +40,23 @@ rep.int(x, ...)
}
\seealso{
- \code{base::\link[base]{rep.int}} for the default \code{rep.int},
- \code{intersect}, and \code{setdiff} methods.
+ \itemize{
+ \item \code{base::\link[base]{rep.int}} for the default \code{rep.int},
+ \code{intersect}, and \code{setdiff} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{rep.int,Rle-method} in the IRanges package
- for an example of a specific \code{rep.int} method (defined for
- \link[IRanges]{Rle} objects).
+ \item \link[IRanges]{rep.int,Rle-method} in the IRanges package
+ for an example of a specific \code{rep.int} method (defined for
+ \link[IRanges]{Rle} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/residuals.Rd b/man/residuals.Rd
index a2800cf..2e6399e 100644
--- a/man/residuals.Rd
+++ b/man/residuals.Rd
@@ -31,21 +31,23 @@ residuals(object, ...)
}
\seealso{
- \code{stats::\link[stats]{residuals}} for the default \code{residuals}
- method.
+ \itemize{
+ \item \code{stats::\link[stats]{residuals}} for the default
+ \code{residuals} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[affyPLM]{residuals,PLMset-method} in the affyPLM package
- for an example of a specific \code{residuals} method (defined for
- \link[affyPLM]{PLMset} objects).
+ \item \link[affyPLM]{residuals,PLMset-method} in the affyPLM package
+ for an example of a specific \code{residuals} method (defined for
+ \link[affyPLM]{PLMset} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/row_colnames.Rd b/man/row_colnames.Rd
index 27bbfe9..b87fdf8 100644
--- a/man/row_colnames.Rd
+++ b/man/row_colnames.Rd
@@ -7,7 +7,7 @@
\title{Row and column names}
\description{
- Retrieve the row or column names of a matrix-like R object.
+ Retrieve the row or column names of a matrix-like object.
NOTE: This man page is for the \code{rownames} and \code{colnames}
\emph{S4 generic functions} defined in the BiocGenerics package.
@@ -24,7 +24,7 @@ colnames(x, do.NULL=TRUE, prefix="col")
\arguments{
\item{x}{
- A matrix-like R object.
+ A matrix-like object.
}
\item{do.NULL, prefix}{
See \code{?base::\link[base]{rownames}} for a description of
@@ -43,21 +43,23 @@ colnames(x, do.NULL=TRUE, prefix="col")
}
\seealso{
- \code{base::\link[base]{rownames}} for the default \code{rownames} and
- \code{colnames} methods.
+ \itemize{
+ \item \code{base::\link[base]{rownames}} for the default \code{rownames}
+ and \code{colnames} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{rownames,DataFrame-method} in the IRanges package
- for an example of a specific \code{rownames} method (defined for
- \link[IRanges]{DataFrame} objects).
+ \item \link[IRanges]{rownames,DataFrame-method} in the IRanges package
+ for an example of a specific \code{rownames} method (defined for
+ \link[IRanges]{DataFrame} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/sets.Rd b/man/sets.Rd
index 301580c..f84faee 100644
--- a/man/sets.Rd
+++ b/man/sets.Rd
@@ -9,7 +9,7 @@
\description{
Performs \emph{set} union, intersection and (asymmetric!) difference
- on two vector-like R objects.
+ on two vector-like objects.
NOTE: This man page is for the \code{union}, \code{intersect} and
\code{setdiff} \emph{S4 generic functions} defined in the BiocGenerics
@@ -28,7 +28,7 @@ setdiff(x, y, ...)
\arguments{
\item{x, y}{
- R objects of the same class (typically a vector-like class).
+ Vector-like objects (typically of the same class, but not necessarily).
}
\item{...}{
Additional arguments, for use in specific methods.
@@ -61,21 +61,23 @@ setdiff(x, y, ...)
}
\seealso{
- \code{base::\link[base]{union}} for the default \code{union},
- \code{intersect}, and \code{setdiff} methods.
+ \itemize{
+ \item \code{base::\link[base]{union}} for the default \code{union},
+ \code{intersect}, and \code{setdiff} methods.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[GenomicRanges]{union,GRanges,GRanges-method} in the GenomicRanges
- package for an example of a specific \code{union} method (defined for
- \link[GenomicRanges]{GRanges} objects).
+ \item \link[GenomicRanges]{union,GRanges,GRanges-method} in the
+ GenomicRanges package for an example of a specific \code{union}
+ method (defined for \link[GenomicRanges]{GRanges} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/sort.Rd b/man/sort.Rd
index b58b0ca..ad52ab8 100644
--- a/man/sort.Rd
+++ b/man/sort.Rd
@@ -21,7 +21,7 @@ sort(x, decreasing=FALSE, ...)
\arguments{
\item{x}{
- A vector-like R object.
+ A vector-like object.
}
\item{decreasing, ...}{
See \code{?base::\link[base]{sort}} for a description of
@@ -52,21 +52,23 @@ sort(x, decreasing=FALSE, ...)
}
\seealso{
- \code{base::\link[base]{sort}} for the default
- \code{sort} method.
+ \itemize{
+ \item \code{base::\link[base]{sort}} for the default
+ \code{sort} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{sort,Vector-method} in the IRanges package
- for an example of a specific \code{sort} method (defined for
- \link[IRanges]{Vector} objects).
+ \item \link[IRanges]{sort,Vector-method} in the IRanges package
+ for an example of a specific \code{sort} method (defined for
+ \link[IRanges]{Vector} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/strand.Rd b/man/strand.Rd
index 731dfa5..f5fdb54 100644
--- a/man/strand.Rd
+++ b/man/strand.Rd
@@ -36,18 +36,20 @@ strand(x, ...) <- value
}
\seealso{
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \itemize{
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[GenomicRanges]{strand,GRanges-method} in the GenomicRanges
- package for the method defined for \link[GenomicRanges]{GRanges}
- objects.
+ \item \link[GenomicRanges]{strand,GRanges-method} in the GenomicRanges
+ package for an example of a specific \code{strand} method (defined
+ for \link[GenomicRanges]{GRanges} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/table.Rd b/man/table.Rd
index 5ad7662..6421b91 100644
--- a/man/table.Rd
+++ b/man/table.Rd
@@ -22,7 +22,7 @@ table(...)
\arguments{
\item{...}{
- One or more R objects which can be interpreted as factors
+ One or more objects which can be interpreted as factors
(including character strings), or a list (or data frame)
whose components can be so interpreted.
}
@@ -37,20 +37,22 @@ table(...)
}
\seealso{
- \code{base::\link[base]{table}} for the default \code{table} method.
+ \itemize{
+ \item \code{base::\link[base]{table}} for the default \code{table} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{table,Rle-method} in the IRanges package
- for an example of a specific \code{table} method (defined
- for \link[IRanges]{Rle} objects).
+ \item \link[IRanges]{table,Rle-method} in the IRanges package
+ for an example of a specific \code{table} method (defined for
+ \link[IRanges]{Rle} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/tapply.Rd b/man/tapply.Rd
index 9554d12..8510857 100644
--- a/man/tapply.Rd
+++ b/man/tapply.Rd
@@ -24,7 +24,7 @@ tapply(X, INDEX, FUN=NULL, ..., simplify=TRUE)
\arguments{
\item{X}{
- A list-like or vector-like R object.
+ A list-like or vector-like object.
}
\item{INDEX, FUN, ..., simplify}{
See \code{?base::\link[base]{tapply}} for a description of
@@ -41,20 +41,23 @@ tapply(X, INDEX, FUN=NULL, ..., simplify=TRUE)
}
\seealso{
- \code{base::\link[base]{tapply}} for the default \code{tapply} method.
+ \itemize{
+ \item \code{base::\link[base]{tapply}} for the default \code{tapply}
+ method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{tapply,Vector-method} in the IRanges package
- for an example of a specific \code{tapply} method (defined for
- \link[IRanges]{Vector} objects).
+ \item \link[IRanges]{tapply,Vector-method} in the IRanges package
+ for an example of a specific \code{tapply} method (defined for
+ \link[IRanges]{Vector} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/unique.Rd b/man/unique.Rd
index 0800350..0e6a5d0 100644
--- a/man/unique.Rd
+++ b/man/unique.Rd
@@ -6,7 +6,7 @@
\description{
\code{unique} returns an object of the same class as \code{x} (typically
- a vector-like, data-frame-like, or array-like R object) but with duplicate
+ a vector-like, data-frame-like, or array-like object) but with duplicate
elements/rows removed.
NOTE: This man page is for the \code{unique} \emph{S4 generic function}
@@ -24,7 +24,7 @@ unique(x, incomparables=FALSE, ...)
\arguments{
\item{x}{
- A vector-like, data-frame-like, or array-like R object.
+ A vector-like, data-frame-like, or array-like object.
}
\item{incomparables, ...}{
See \code{?base::\link[base]{unique}} for a description of
@@ -44,23 +44,26 @@ unique(x, incomparables=FALSE, ...)
}
\seealso{
- \code{base::\link[base]{unique}} for the default \code{unique} method.
+ \itemize{
+ \item \code{base::\link[base]{unique}} for the default \code{unique}
+ method.
- \code{BiocGenerics::\link[BiocGenerics]{duplicated}} for determining
- duplicate elements.
+ \item \code{BiocGenerics::\link[BiocGenerics]{duplicated}} for determining
+ duplicate elements.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{unique,Rle-method} in the IRanges package
- for an example of a specific \code{unique} method (defined for
- \link[IRanges]{Rle} objects).
+ \item \link[IRanges]{unique,Rle-method} in the IRanges package
+ for an example of a specific \code{unique} method (defined for
+ \link[IRanges]{Rle} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/unlist.Rd b/man/unlist.Rd
index 2a0f153..ffd120b 100644
--- a/man/unlist.Rd
+++ b/man/unlist.Rd
@@ -24,7 +24,7 @@ unlist(x, recursive=TRUE, use.names=TRUE)
\arguments{
\item{x}{
- A list-like R object.
+ A list-like object.
}
\item{recursive, use.names}{
See \code{?base::\link[base]{unlist}} for a description of
@@ -41,21 +41,23 @@ unlist(x, recursive=TRUE, use.names=TRUE)
}
\seealso{
- \code{base::\link[base]{unlist}} for the default
- \code{unlist} method.
+ \itemize{
+ \item \code{base::\link[base]{unlist}} for the default
+ \code{unlist} method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{unlist,List-method} in the IRanges package
- for an example of a specific \code{unlist} method (defined for
- \link[IRanges]{List} objects).
+ \item \link[IRanges]{unlist,List-method} in the IRanges package
+ for an example of a specific \code{unlist} method (defined for
+ \link[IRanges]{List} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/updateObject.Rd b/man/updateObject.Rd
index e6bd33f..47154c2 100644
--- a/man/updateObject.Rd
+++ b/man/updateObject.Rd
@@ -107,21 +107,23 @@ getObjectSlots(object)
}
\seealso{
- \code{\link[Biobase]{updateObjectTo}} in the Biobase package for
- updating an object to the class definition of a template (might
- be useful for updating a virtual superclass).
+ \itemize{
+ \item \code{\link[Biobase]{updateObjectTo}} in the Biobase package for
+ updating an object to the class definition of a template (might
+ be useful for updating a virtual superclass).
- \code{\link[methods]{validObject}} for testing the validity of an
- object.
+ \item \code{\link[methods]{validObject}} for testing the validity of an
+ object.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/weights.Rd b/man/weights.Rd
index e3a67ea..ce9ab9c 100644
--- a/man/weights.Rd
+++ b/man/weights.Rd
@@ -37,21 +37,23 @@ weights(object, ...)
}
\seealso{
- \code{stats::\link[stats]{weights}} for the default \code{weights}
- method.
+ \itemize{
+ \item \code{stats::\link[stats]{weights}} for the default \code{weights}
+ method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[affyPLM]{weights,PLMset-method} in the affyPLM package
- for an example of a specific \code{weights} method (defined for
- \link[affyPLM]{PLMset} objects).
+ \item \link[affyPLM]{weights,PLMset-method} in the affyPLM package
+ for an example of a specific \code{weights} method (defined for
+ \link[affyPLM]{PLMset} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/man/xtabs.Rd b/man/xtabs.Rd
index e7714b6..96a467b 100644
--- a/man/xtabs.Rd
+++ b/man/xtabs.Rd
@@ -28,7 +28,7 @@ xtabs(formula=~., data=parent.frame(), subset, sparse=FALSE,
these arguments.
}
\item{data}{
- A data-frame-like R object.
+ A data-frame-like object.
}
}
@@ -41,20 +41,23 @@ xtabs(formula=~., data=parent.frame(), subset, sparse=FALSE,
}
\seealso{
- \code{stats::\link[stats]{xtabs}} for the default \code{xtabs} method.
+ \itemize{
+ \item \code{stats::\link[stats]{xtabs}} for the default \code{xtabs}
+ method.
- \code{\link[methods]{showMethods}} for displaying a summary of the
- methods defined for a given generic function.
+ \item \code{\link[methods]{showMethods}} for displaying a summary of the
+ methods defined for a given generic function.
- \code{\link[methods]{selectMethod}} for getting the definition of
- a specific method.
+ \item \code{\link[methods]{selectMethod}} for getting the definition of
+ a specific method.
- \link[IRanges]{xtabs,DataTable-method} in the IRanges package
- for an example of a specific \code{xtabs} method (defined for
- \link[IRanges]{DataTable} objects).
+ \item \link[IRanges]{xtabs,DataTable-method} in the IRanges package
+ for an example of a specific \code{xtabs} method (defined for
+ \link[IRanges]{DataTable} objects).
- \link{BiocGenerics} for a summary of all the generics defined
- in the BiocGenerics package.
+ \item \link{BiocGenerics} for a summary of all the generics defined
+ in the BiocGenerics package.
+ }
}
\examples{
diff --git a/R/tapply.R b/R/append.R
similarity index 52%
copy from R/tapply.R
copy to R/append.R
index 79d6c9d..17e4ca7 100644
--- a/R/tapply.R
+++ b/R/append.R
@@ -1,10 +1,10 @@
### =========================================================================
-### The tapply() generic
+### The append() generic
### -------------------------------------------------------------------------
###
### Need to explicitly define this generic otherwise the implicit generic in
-### package "base" would dispatch on all its arguments. Here we set dispatch
-### on the 1st arg (the 'X' arg) only!
+### package "base" would dispatch on ('x', 'values', 'after'). Here we set
+### dispatch on the first two args (the 'x' and 'values' args) only!
-setGeneric("tapply", signature="X")
+setGeneric("append", signature=c("x", "values"))
--
Alioth's /git/debian-med/git-commit-notice on /srv/git.debian.org/git/debian-med/r-bioc-biocgenerics.git
More information about the debian-med-commit
mailing list